@@ -10,7 +10,7 @@ Siebel::Srvrmgr::Daemon - super class for sessions with Siebel srvrmgr program
 
     package MyDaemon;
 
-	extends 'Siebel::Srvrmgr::Daemon';
+    extends 'Siebel::Srvrmgr::Daemon';
 
 =head1 DESCRIPTION
 
@@ -46,6 +46,7 @@ use Fcntl ':flock';    # import LOCK_* constants
 use Config;
 use Carp;
 use File::Spec;
+use Data::Dumper;
 
 my $SIG_INT   = 0;
 my $SIG_PIPE  = 0;
@@ -511,6 +512,10 @@ ALRM
 
 =back
 
+Also the method sets the environment variable C<SIEBEL_TZ> if a time zone was set.
+
+If the logging is set to C<DEBUG> level all attribute values will be logged.
+
 =cut
 
 sub BUILD {
@@ -522,6 +527,35 @@ sub BUILD {
     $SIG{ALRM} = sub { $SIG_ALARM = 1 };
     $ENV{SIEBEL_TZ} = $self->get_time_zone();
 
+    my $logger = Siebel::Srvrmgr->gimme_logger( blessed($self) );
+
+    if ( $logger->is_debug() ) {
+
+        $logger->debug('This instance attributes values:');
+
+        foreach my $attrib ( $self->meta->get_all_attributes() ) {
+
+            my $getter = $attrib->get_read_method();
+            my $value  = $self->$getter;
+            $value = 'UNDEFINED' unless ( defined($value) );
+
+            if ( ref($value) ne '' ) {
+
+                $logger->debug(
+                    'attribute ' . $attrib->name() . ' = ' . Dumper($value) );
+
+            }
+            else {
+
+                $logger->debug(
+                    'attribute ' . $attrib->name() . ' = ' . $value );
+
+            }
+
+        }
+
+    }
+
 }
 
 =head2 reset_retries
@@ -729,8 +763,7 @@ sub _define_params {
         $self->get_bin(),        '/e',
         $self->get_enterprise(), '/g',
         $self->get_gateway(),    '/u',
-        $self->get_user(),       '/p',
-        $self->get_password(),   '/l',
+        $self->get_user(),       '/l',
         $self->get_lang_id()
 
     );
@@ -738,6 +771,9 @@ sub _define_params {
     push( @params, '/s', $self->get_server() )
       if ( defined( $self->get_server() ) );
 
+    push( @params, '/k', $self->get_field_del() )
+      if ( defined( $self->get_field_del() ) );
+
 # :WORKAROUND:06/08/2013 21:05:32:: if a perl script will be executed (like for automated testing of this distribution)
 # then the perl interpreter must be part of the command path to avoid calling cmd.exe in Microsoft Windows
     unshift( @params, $Config{perlpath} ) if ( $self->use_perl() );
@@ -756,7 +792,7 @@ sub get_lock_file {
 
     my $self = shift;
 
-    my $filename = $self->blessed();
+    my $filename = blessed($self);
     $filename =~ s/\:{2}/_/g;
 
     return File::Spec->catfile( $self->get_lock_dir, ( $filename . '.lock' ) );
@@ -770,6 +806,9 @@ our $adm_02049    = qr/^SBL-ADM-02049.*/;
 our $adm_02751    = qr/^SBL-ADM-02751.*/;
 our $siebel_error = SIEBEL_ERROR;
 
+# Fatal error (2555922): (null), exiting...
+our $fatal_error = qr/Fatal error.*exiting\.\.\./;
+
 # this method will check for errors and warnings, specially if read from STDERR.
 # the first parameter is the data to be check, which can be an array reference or scalar, both will be checked the same way
 # the seconds parameter tells if the data was read from STDERR or not. If read from STDERR, data will be logged as warnings
@@ -780,7 +819,7 @@ sub _check_error {
     my $content  = shift;
     my $is_error = shift;    #boolean
 
-    my $logger = Siebel::Srvrmgr->gimme_logger( $self->blessed() );
+    my $logger = Siebel::Srvrmgr->gimme_logger( blessed($self) );
 
 # :WORKAROUND: to enable the code to process both scalar and array reference data
 # without duplicating code
@@ -794,6 +833,12 @@ sub _check_error {
 
     foreach my $line ( @{$content} ) {
 
+        if ( $line =~ $fatal_error ) {
+
+            $logger->logdie("Failed to connect to: [$line]");
+
+        }
+
         if ( $line =~ $siebel_error ) {
 
           SWITCH: {
@@ -865,7 +910,7 @@ sub DEMOLISH {
 
     my $self = shift;
 
-    my $logger = Siebel::Srvrmgr->gimme_logger( $self->blessed() );
+    my $logger = Siebel::Srvrmgr->gimme_logger( blessed($self) );
 
     $logger->info('Terminating daemon: preparing cleanup');
 
@@ -916,7 +961,7 @@ sub _create_lock {
 
     my $self = shift;
 
-    my $logger = Siebel::Srvrmgr->gimme_logger( $self->blessed() );
+    my $logger = Siebel::Srvrmgr->gimme_logger( blessed($self) );
 
     my $lock_file = $self->get_lock_file;
 
@@ -953,7 +998,7 @@ sub _del_lock {
     my $self      = shift;
     my $lock_file = $self->get_lock_file;
 
-    my $logger = Siebel::Srvrmgr->gimme_logger( $self->blessed() );
+    my $logger = Siebel::Srvrmgr->gimme_logger( blessed($self) );
 
     if ( -e $lock_file ) {
 
