@@ -39,6 +39,8 @@ Considering this situation, the interface of this class should be considered exp
 
 =cut
 
+use warnings;
+use strict;
 use MooseX::Singleton;
 
 =pod
