@@ -4,13 +4,13 @@ package Siebel::Srvrmgr::Daemon::Heavy;
 
 =head1 NAME
 
-Siebel::Srvrmgr::Daemon::Heavy - "heavier' implementation of Siebel::Srvrmgr::Daemon
+Siebel::Srvrmgr::Daemon::Heavy - "heavier" implementation of Siebel::Srvrmgr::Daemon
 
 =head1 SYNOPSIS
 
-    use Siebel::Srvrmgr::Daemon;
+    use Siebel::Srvrmgr::Daemon::Heavy;
 
-    my $daemon = Siebel::Srvrmgr::Daemon->new(
+    my $daemon = Siebel::Srvrmgr::Daemon::Heavy->new(
         {
             server      => 'servername',
             gateway     => 'gateway',
@@ -18,6 +18,8 @@ Siebel::Srvrmgr::Daemon::Heavy - "heavier' implementation of Siebel::Srvrmgr::Da
             user        => 'user',
             password    => 'password',
             bin         => 'c:\\siebel\\client\\bin\\srvrmgr.exe',
+            time_zone   => 'America/Sao_Paulo',
+            has_lock    => 1, 
             commands    => [
                     Siebel::Srvrmgr::Daemon::Command->new(
                         command => 'load preferences',
@@ -45,8 +47,8 @@ Siebel::Srvrmgr::Daemon::Heavy - "heavier' implementation of Siebel::Srvrmgr::Da
 
 =head1 DESCRIPTION
 
-This class is the "heavier" version of L<Siebel::Srvmrgr::Daemon>. By heavier, understand more complex code to be able to deal with a heavier usage
-of srvrmgr.
+This class extends L<Siebel::Srvmrgr::Daemon>. By "Heavy" understand more complex code to be able to deal with a large number of commands
+of C<srvrmgr>.
 
 This class is indicated to be used in cenarios where several commands need to be executed in a short time interval: it will connect to srvrmgr by using 
 IPC for communication between the processes and once connected, the srvrmgr session will be reused as many times as desired instead of following the
@@ -89,6 +91,10 @@ our $SIG_ALARM = 0;
 
 =pod
 
+=head1 ATTRIBUTES
+
+This class has additional attributes besides those from parent class.
+
 =head2 write_fh
 
 A filehandle reference to the C<srvrmgr> STDIN. This is a read-only attribute.
@@ -140,7 +146,7 @@ has error_fh => (
 
 =head2 read_timeout
 
-The timeout for trying to read from child process handlers in seconds. It defaults to 1 second.
+The timeout for trying to read from child process handlers in seconds. It defaults to 0.5 second.
 
 Changing this value may help improving performance, but should be used with care.
 
@@ -151,7 +157,7 @@ has read_timeout => (
     is      => 'rw',
     writer  => 'set_read_timeout',
     reader  => 'get_read_timeout',
-    default => 0.5 
+    default => 0.5
 );
 
 =pod
@@ -408,12 +414,12 @@ override 'run' => sub {
           unless ( $self->_create_child() );
 
 # :WORKAROUND:31/07/2013 14:42:33:: must initialize the Log::Log4perl after forking the srvrmgr to avoid sharing filehandles
-        $logger = Siebel::Srvrmgr->gimme_logger( $self->blessed(), );
+        $logger = Siebel::Srvrmgr->gimme_logger( blessed($self) );
 
     }
     else {
 
-        $logger = Siebel::Srvrmgr->gimme_logger( $self->blessed(), );
+        $logger = Siebel::Srvrmgr->gimme_logger( blessed($self) );
         $logger->info( 'Reusing PID ', $self->get_pid() )
           if ( $logger->is_debug() );
         $ignore_output = 1;
@@ -650,7 +656,7 @@ override 'run' => sub {
             }
 
 # :WORKAROUND:16/08/2013 18:54:51:: exceptions from validating output are not being seen
-# :TODO      :16/08/2013 18:55:18:: start using TryCatch to use exceptions for known problems
+# :TODO      :16/08/2013 18:55:18:: start using Try::Tiny to use exceptions for known problems
             eval {
 
                 $condition->set_output_used( $action->do( \@input_buffer ) );
@@ -751,7 +757,7 @@ sub _manage_handlers {
     my $self   = shift;
     my $select = shift;    # IO::Select object
 
-    my $logger = Siebel::Srvrmgr->gimme_logger( $self->blessed() );
+    my $logger = Siebel::Srvrmgr->gimme_logger( blessed($self) );
 
     # to keep data from both handles while looping over them
     my %data;
@@ -802,7 +808,7 @@ sub _create_child {
 
     my $self = shift;
 
-    my $logger = Siebel::Srvrmgr->gimme_logger( $self->blessed() );
+    my $logger = Siebel::Srvrmgr->gimme_logger( blessed($self) );
 
     if ( $self->get_retries() >= $self->get_max_retries() ) {
 
@@ -822,6 +828,9 @@ sub _create_child {
 
     my ( $pid, $write_h, $read_h, $error_h ) = safe_open3($params_ref);
 
+  # submit the password, avoiding exposing it in the command line as a parameter
+    syswrite $write_h, ( $self->get_password . "\n" );
+
     $self->_set_pid($pid);
     $self->_set_write($write_h);
     $self->_set_read($read_h);
@@ -858,7 +867,7 @@ sub _process_stderr {
     my $self     = shift;
     my $data_ref = shift;
 
-    my $logger = Siebel::Srvrmgr->gimme_logger( $self->blessed() );
+    my $logger = Siebel::Srvrmgr->gimme_logger( blessed($self) );
 
     if ( defined($$data_ref) ) {
 
@@ -889,7 +898,7 @@ sub _process_stdout {
     my $buffer_ref = shift;
     my $condition  = shift;
 
-    my $logger = Siebel::Srvrmgr->gimme_logger( $self->blessed() );
+    my $logger = Siebel::Srvrmgr->gimme_logger( blessed($self) );
 
 # :TODO      :09/08/2013 19:35:30:: review and remove assigning the compiled regexes to scalar (probably unecessary)
     my $prompt_regex    = SRVRMGR_PROMPT;
@@ -916,7 +925,7 @@ sub _process_stdout {
 
         }
 
-        #$self->_check_error( $line, 0 );
+        $self->_check_error( $line, 0 );
 
       SWITCH: {
 
@@ -994,7 +1003,7 @@ sub _check_child {
 
     my $self = shift;
 
-    my $logger = Siebel::Srvrmgr->gimme_logger( $self->blessed() );
+    my $logger = Siebel::Srvrmgr->gimme_logger( blessed($self) );
 
     if ( $self->has_pid() ) {
 
@@ -1087,7 +1096,7 @@ sub _my_cleanup {
 
     my $self = shift;
 
-    my $logger = Siebel::Srvrmgr->gimme_logger( $self->blessed() );
+    my $logger = Siebel::Srvrmgr->gimme_logger( blessed($self) );
 
     if ( $self->has_pid() and ( $self->get_pid() =~ /\d+/ ) ) {
 
@@ -1177,7 +1186,7 @@ Accepts as an optional parameter an instance of a L<Log::Log4perl> for logging m
 sub close_child {
 
     my $self   = shift;
-    my $logger = Siebel::Srvrmgr->gimme_logger( $self->blessed() );
+    my $logger = Siebel::Srvrmgr->gimme_logger( blessed($self) );
 
     if ( $self->has_pid() ) {
 
