@@ -1,7 +1,6 @@
 package Siebel::Srvrmgr::ListParser::FSA;
 use warnings;
 use strict;
-use Log::Log4perl;
 use Siebel::Srvrmgr;
 use Siebel::Srvrmgr::Regexes qw(SRVRMGR_PROMPT);
 use Scalar::Util qw(weaken);
@@ -68,7 +67,7 @@ sub new {
     my $class   = shift;
     my $map_ref = shift;
 
-    my $logger = Siebel::Srvrmgr->gimme_logger('Siebel::Srvrmgr::ListParser');
+    my $logger = Siebel::Srvrmgr->gimme_logger('Siebel::Srvrmgr::ListParser::FSA');
 
     $logger->logdie('the output type mapping reference received is not valid')
       unless ( ( defined($map_ref) ) and ( ref($map_ref) eq 'HASH' ) );
@@ -318,6 +317,29 @@ sub new {
             ],
             message => 'prompt found'
         },
+        list_procs => {
+            label    => 'parses output from a list procs command',
+            on_enter => sub {
+                my $state = shift;
+                $state->notes( is_cmd_changed => 0 );
+                $state->notes( is_data_wanted => 1 );
+            },
+            on_exit => sub {
+
+                my $state = shift;
+                $state->notes( is_data_wanted => 0 );
+
+            },
+            rules => [
+                command_submission => sub {
+
+                    my $state = shift;
+                    return ( $state->machine->{curr_line} =~ SRVRMGR_PROMPT );
+
+                },
+            ],
+            message => 'prompt found'
+        },
         list_servers => {
             label    => 'parses output from a list servers command',
             on_enter => sub {
@@ -419,9 +441,9 @@ sub new {
                   Siebel::Srvrmgr->gimme_logger('Siebel::Srvrmgr::ListParser');
                 if ( $logger->is_debug() ) {
 
-                    $logger->debug( 'command_submission got ['
-                          . $state->notes('line')
-                          . ']' );
+                    my $line = $state->notes('line');
+                    $logger->debug( 'command_submission got [' . $line . ']' )
+                      if ( defined($line) );
 
                 }
 
@@ -545,6 +567,24 @@ sub new {
 
                     }
 
+                },
+                list_procs => sub {
+
+                    my $state = shift;
+
+                    if ( $state->notes('last_command') =~
+                        $map_ref->{list_procs} )
+                    {
+
+                        return 1;
+
+                    }
+                    else {
+
+                        return 0;
+
+                    }
+
                 },
                 list_servers => sub {
 
