@@ -2,6 +2,8 @@ package Siebel::Srvrmgr::ListParser::Output::Duration;
 
 use Moose::Role;
 use Carp;
+use warnings;
+use strict;
 
 # :TODO:06-06-2015 01:53:30:: check possibility to use DateTime::Tiny instead
 use DateTime;
