@@ -4,6 +4,8 @@ use Moose;
 use Proc::ProcessTable;
 use namespace::autoclean;
 use Set::Tiny;
+use Carp qw(cluck confess);
+use Siebel::Srvrmgr::OS::Process;
 
 =pod
 
@@ -16,11 +18,19 @@ Siebel::Srvrmgr::OS::Unix - module to recover information from OS processes of S
     use Siebel::Srvrmgr::OS::Unix;
     my $procs = Siebel::Srvrmgr::OS::Unix->new(
         {
-            enterprise_log => $enterprise_log,
-            cmd_regex      => "^$path_to_siebel_dir",
-            parent_regex => 'Created\s(multithreaded\s)?server\sprocess\s\(OS\spid\s\=\s+\d+\s+\)\sfor\s\w+'
+            comps_source =>
+              Siebel::Srvrmgr::Log::Enterprise::Parser::Comp_alias->new(
+                {
+                    process_regex => 'Created\s(multithreaded)?\sserver\sprocess', 
+                    log_path => $enterprise_log,
+                    archive  => Archive->new( { dbm_path => $MY_DBM } )
+                }
+              ),
+            cmd_regex => $siebel_path,
         }
     );
+
+    # hash reference of objects Siebel::Srvrmgr::OS::Process
     my $procs_ref = $procs->get_procs;
     foreach my $comp_pid( keys( %{$procs_ref} ) ) {
 
@@ -32,49 +42,25 @@ Siebel::Srvrmgr::OS::Unix - module to recover information from OS processes of S
 
 This module is a L<Moose> class.
 
-It is responsible to recover information from a UNIX-like operation system to be able to merge with information
-regarding Siebel components.
+It is responsible to recover information from processes executing on a UNIX-like O.S. and merging that with information of Siebel components.
 
-This class represents the processes of a single Siebel Server and will recover processes information from C</proc> directory.
-
-Additionally, this class has a method to search the Siebel enterprise log file for processes information as well.
+Details on running processes are recovered from C</proc> directory meanwhile the details about the components are read from a class that implements the L<Siebel::Srvrmgr::Comps_source> role.
 
 =head1 ATTRIBUTES
 
-=head2 enterprise_log
+=head2 comps_source
 
 Required attribute.
 
-A string of the complete path name to the Siebel enterprise log file.
+An instance of a class that implements the Moose Role L<Siebel::Srvrmgr::Comps_source>. Those classes are supposed to recover information about the current modules available in a Siebel Server.
 
 =cut
 
-has enterprise_log => (
-    is       => 'rw',
-    isa      => 'Str',
-    reader   => 'get_ent_log',
-    writer   => 'set_ent_log',
-    required => 1
-);
-
-=head2 parent_regex
-
-Required attribute.
-
-A string of the regular expression to match the components PID logged in the Siebel Enterprise log file.
-
-Since the enterprise may contain different language settings, this parameter is required and will depend on the language set.
-
-This attribute is a string, not a compiled regular expression with C<qr>.
-
-=cut
-
-has parent_regex => (
-    is       => 'rw',
-    isa      => 'Str',
-    reader   => 'get_parent_regex',
-    writer   => 'set_parent_regex',
-    required => 1
+has comps_source => (
+    is       => 'ro',
+    does     => 'Siebel::Srvrmgr::Comps_source',
+    required => 1,
+    reader   => 'get_comps_source'
 );
 
 =head2 cmd_regex
@@ -179,97 +165,19 @@ has limits_callback => (
     writer => 'set_callback'
 );
 
-=head2 last_line
-
-The last line read from the Siebel Enterprise log. One can use this attribute to avoid reading again the whole Siebel Enterprise log file.
-
-The atribute holds an integer, which is by default zero and is also read-only.
-
-It will be updated internally only if the attribute C<use_last_line> is set to true.
-
-=cut
-
-has last_line => ( is => 'ro', isa => 'Int', reader => 'get_last_line', writer => '_set_last_line', default => 0 );
-
-=head2 use_last_line
-
-A boolean attribute, by default set to false.
-
-If set to true, the attribute C<last_line> will be updated with the last line number read from the Siebel Enterprise log file.
-
-=cut
-
-has use_last_line => ( is => 'ro', isa => 'Bool', reader => 'use_last_line', default => 0 );
-
 =head1 METHODS
 
+=head2 new
+
+To create new instances of Siebel::Srvrmgr::OS::Unix.
+
+The constructor expects a hash reference with the attributes required plus those that are marked as optional.
+
 =head2 get_procs
 
-Searches through C</proc> and the Siebel Enterprise log file and returns an hash reference with the pids as keys and hashes references as values.
-For those hash references, the following keys will be available:
+Searches through C</proc> and and returns an hash reference with the pids as keys and L<Siebel::Srvrmgr::OS::Process> instances as values.
 
-=over
-
-=item *
-
-fname: name of the process
-
-=item *
-
-pctcpu: % of server total CPU
-
-=item *
-
-pctmem: % of server total memory
-
-=item *
-
-rss: RSS
-
-=item *
-
-vsz: VSZ
-
-=item *
-
-comp_alias: alias of the Siebel Component. If the PID is not related to a Siebel component process (for example, the process of the Siebel Gateway)
-this key value will be "N/A" by default.
-
-=back
-
-The only process informations will be those match C<cmd_regex> and that have C<fname> equal one of the following values:
-
-=over 
-
-=item *
-
-siebmtsh
-
-=item *
-
-siebmtshmw
-
-=item *
-
-siebproc
-
-=item *
-
-siebprocmw
-
-=item *
-
-siebsess
-
-=item *
-
-siebsh
-
-=item *
-
-siebshmw
-
-=back
+Those instances will be created by merging information from C</proc> and the C<comps_source> attribute instance.
 
 =cut
 
@@ -285,11 +193,6 @@ sub get_procs {
 
     }
 
-    my $server_procs = Set::Tiny->new(
-        'siebmtsh', 'siebmtshmw', 'siebproc', 'siebprocmw',
-        'siebsess', 'siebsh',     'siebshmw'
-    );
-
     my $t = Proc::ProcessTable->new( enable_ttys => 0 );
 
     my %procs;
@@ -303,24 +206,16 @@ sub get_procs {
         $pctcpu =~ s/\s//;
         $pctcpu += 0;
 
-        $procs{ $process->pid } = {
-            fname  => $process->fname,
-            pctcpu => $pctcpu,
-            pctmem => ( $process->pctmem + 0 ),
-            rss    => ( $process->rss + 0 ),
-            vsz    => ( $process->size + 0 )
-        };
-
-        if ( $server_procs->has( $process->fname ) ) {
-
-            $procs{ $process->pid }->{comp_alias} = 'unknown';
-
-        }
-        else {
-
-            $procs{ $process->pid }->{comp_alias} = 'N/A';
-
-        }
+        $procs{ $process->pid } = Siebel::Srvrmgr::OS::Process->new(
+            {
+                pid    => $process->pid,
+                fname  => $process->fname,
+                pctcpu => $pctcpu,
+                pctmem => ( $process->pctmem + 0 ),
+                rss    => ( $process->rss + 0 ),
+                vsz    => ( $process->size + 0 )
+            }
+        );
 
         if ( $self->get_mem_limit > 0 ) {
 
@@ -365,90 +260,17 @@ sub get_procs {
 
     }
 
-    $self->_find_pid( \%procs );
+    $self->find_comps( \%procs );
 
     return \%procs;
 
 }
 
-sub _find_pid {
+sub find_comps {
 
     my $self      = shift;
     my $procs_ref = shift;
-    my %comps;
-
-    my $create_regex;
-
-    {
-
-        my $regex = $self->get_parent_regex;
-        $create_regex = qr/$regex/;
-
-    }
-
-    local $/ = "\015\012";
-
-    open( my $in, '<', $self->get_ent_log )
-      or die( 'Cannot read ' . $self->get_ent_log . ": $!" );
-      
-    my $last_line = $self->get_last_line();
-    
-    # WORKAROUND: to avoid testing for every line of the log file read, the while loop was duplicated
-    if ( $self->use_last_line() ) {
-
-        while ( my $line = <$in> ) {
-        
-            next unless( ( $last_line == 0 ) or ( $. > $last_line ) );
-            chomp($line);
-            my @parts = split( /\t/, $line );
-
-            if ( $line =~ $create_regex ) {
-
-                $parts[7] =~ s/\s(\w)+\s//;
-                $parts[7] =~ tr/)//d;
-
-                # pid => component alias
-                $comps{ $parts[6] } = $parts[7];
-                next;
-
-            }
-
-        }
-    
-    } else {
-
-        while ( my $line = <$in> ) {
-        
-            chomp($line);
-            my @parts = split( /\t/, $line );
-
-            if ( $line =~ $create_regex ) {
-
-                $parts[7] =~ s/\s(\w)+\s//;
-                $parts[7] =~ tr/)//d;
-
-                # pid => component alias
-                $comps{ $parts[6] } = $parts[7];
-                next;
-
-            }
-
-        }
-    
-    }
-
-    $self->_set_last_line( $. ) if ( $self->use_last_line() );
-    close($in);
-
-    foreach my $proc_pid ( keys( %{$procs_ref} ) ) {
-
-        if ( exists( $comps{$proc_pid} ) ) {
-
-            $procs_ref->{$proc_pid}->{comp_alias} = $comps{$proc_pid};
-
-        }
-
-    }
+    $self->get_comps_source()->find_comps($procs_ref);
 
 }
 
@@ -464,6 +286,18 @@ L<Moose>
 
 L<Proc::ProcessTable>
 
+=item *
+
+L<Siebel::Srvrmgr::Log::Enterprise::Parser::Comp_alias>
+
+=item *
+
+L<Siebel::Srvrmgr::Comps_source>
+
+=item *
+
+L<Siebel::Srvrmgr::OS::Process>
+
 =back
 
 =head1 AUTHOR
@@ -472,7 +306,7 @@ Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 of Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.orgE<gt>
+This software is copyright (c) 2015 of Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.orgE<gt>
 
 This file is part of Siebel Monitoring Tools.
 
