@@ -236,13 +236,13 @@ sub class_attributes : Tests(no_plan) {
         'field_delimiter', 'time_zone'
     );
 
+        $test->num_method_tests( 'class_attributes', scalar(@attribs) );
+
     if (    ( defined($attribs_ref) )
         and ( ref($attribs_ref) eq 'ARRAY' )
         and ( scalar( @{$attribs_ref} ) > 0 ) )
     {
 
-        $test->num_method_tests( 'class_attributes',
-            scalar(@attribs) + scalar( @{$attribs_ref} ) );
         foreach my $attribute ( @attribs, @{$attribs_ref} ) {
 
             has_attribute_ok( $test->{daemon}, $attribute );
@@ -252,7 +252,6 @@ sub class_attributes : Tests(no_plan) {
     }
     else {
 
-        $test->num_method_tests( 'class_attributes', scalar(@attribs) );
         foreach my $attribute (@attribs) {
 
             has_attribute_ok( $test->{daemon}, $attribute );
